//Beam Check
function WaterDrinkBeamCheck(%player,%pos,%len,%masks,%vec)
{
	%beam = vectorScale(%vec,%len); //vector with magnitude
	%end = vectorAdd(%pos,%beam); //endpoint
	%ray = containerRayCast(%pos,%end,%masks,%player); //do raycast
	%col = firstWord(%ray); //get col object
	return %col; //return col object
}

//WaterDrink Global Silent Loop
function WaterDrinkGlobalSilentLoop(%player)
{
	if(!$Pref::WaterDrinking::On) //if Pref: WaterDrinking disabled
		return; //stop here
	for(%i=0;%i<ClientGroup.getCount();%i++) //search through all clients
	{
		%client = ClientGroup.getObject(%i); //individual client, number i
		if(!isObject(%player = %client.player) || %player.getState() $= "Dead" || !isObject(%client)) //if player DNE, or player is dead, or player's client DNE
			continue; //skip player, and continue looping
		WaterDrinkStateCheck(%player); //check for Water to Drink
		%isWaterDrinker = true; //since at least one player was WaterDrink-ready
	}

	if(%isWaterDrinker) //if an WaterDrinker exists
	{
		cancel($WaterDrink::SilentLoop); //cancel any pending Silent Loop schedules
		$WaterDrink::SilentLoop = scheduleNoQuota(1,0,WaterDrinkGlobalSilentLoop); //continue the loop
	}
}

//WaterDrink Check
function WaterDrinkStateCheck(%player)
{
//	talk("Water Drink, State Check called");
	%swim = %player.getWaterCoverage(); //find water height relative to player
	if(%swim == 1) //if fully submerged
	{
	//	talk("Water Coverage = " SPC %swim); //Confirm water height
		if(%player.getDamageLevel() == 0) //if player has full Health
			return; //stop here
		%player.setDamageLevel(0); //Heal completely
	}
}
//WaterDrink Check
function WaterDrinkGlass(%player)
{
//	talk("Water Drink, Glass called");
	%eyePoint = %player.getEyePoint(); //eye position
	%vec = %player.getEyeVector(); //eye vector
	%col = WaterDrinkBeamCheck(%player,%eyePoint,4,$TypeMasks::fxBrickObjectType | $TypeMasks::TerrainObjectType,%vec); //check for bricks and terrain (bug fix)
	if(isObject(%col) && (%col.getType() & $TypeMasks::fxBrickObjectType)) //if col is a brick
	{
	//	talk("Water Drink, water color ID = " SPC %waterColorID);
		%data = %col.getDatablock().getName(); //brick's datablock, in name
		%waterColorID = getClosestPaintColor(0 SPC 1 SPC 1 SPC 0.5); //turqoise water color
	//	talk("Water, Drink, data = " SPC %data);
		if((%data $= brick1x1RoundData || %data $= brick1x1ConeData) && (%col.colorID == %waterColorID && %col.colorFxID == 4 && %col.shapeFxID == 1)) //if in correct format
		{
		//	talk("Found Water!!!!");
			if(%player.getDamageLevel() == 0) //if player has full Health
				return; //stop here
			%col.fakeKillBrick("0 0 15"); //remove water Glass
			%col.schedule(10*(1000),respawn); //respawn water Glass
			%player.setDamageLevel(0); //Heal completely
		}
	}
}

package WaterDrinking
{
	function Player::ActivateStuff(%player)
	{
		WaterDrinkGlass(%player);
		Parent::activateStuff(%player);
	}
	//on Datablock Change
	function Armor::onNewDatablock(%data,%player)
	{
		Parent::onNewDatablock(%data,%player); //Parent default fcn
		if(isObject(%player.client)) //if client exists (i.e. Real Player Character)
			schedule(1,0,WaterDrinkGlobalSilentLoop); //start the Global Silent Loop
	}
};activatePackage(WaterDrinking);

//Space Guy's Color Matching
function getClosestPaintColor(%rgba)
{
	%prevdist = 100000;
	%colorMatch = 0;
	for(%i = 0;%i < 64;%i++)
	{
		%color = getColorIDTable(%i);
		if(vectorDist(%rgba,getWords(%color,0,2)) < %prevdist && getWord(%rgba,3) - getWord(%color,3) < 0.3 && getWord(%rgba,3) - getWord(%color,3) > -0.3)
		{
			%prevdist = vectorDist(%rgba,%color);
			%colormatch = %i;
		}
	}
	return %colormatch;
}